@@ -30,6 +30,7 @@ use crate::setting::{Setting, SettingValue};
 
 const SENDER_ID: u16 = 0x42;
 const NUM_WORKERS: usize = 10;
+const SETTINGS_WRITE_TIMEOUT_MS: u64 = 1000;
 
 pub struct Client<'a> {
     link: Link<'a, ()>,
@@ -73,7 +74,8 @@ impl<'a> Client<'a> {
         name: impl Into<String>,
         value: impl Into<String>,
     ) -> Result<Entry, Error> {
-        let (ctx, _ctx_handle) = Context::new();
+        let (ctx, _ctx_handle) =
+            Context::with_timeout(Duration::from_millis(SETTINGS_WRITE_TIMEOUT_MS));
         self.write_setting_ctx(group, name, value, ctx)
     }
 
